=== modified file 'loggerhead/controllers/download_ui.py'
--- loggerhead/controllers/download_ui.py	2011-07-07 19:15:35 +0000
+++ loggerhead/controllers/download_ui.py	2011-11-24 07:42:58 +0000
@@ -79,7 +79,7 @@
     def __call__(self, environ, start_response):
         """Stream a tarball from a bazaar branch."""
         # Tried to re-use code from downloadui, not very successful
-        format = "tar"
+        archive_format = "tgz"
         history = self._history
         self.args = self.get_args(environ)
         if len(self.args):
@@ -88,13 +88,13 @@
             revid = self.get_revid()
         if self._branch.export_tarballs:
             root = 'branch'
-            encoded_filename = self.encode_filename(root + '.' + format)
+            encoded_filename = self.encode_filename(root + '.' + archive_format)
             headers = [
                 ('Content-Type', 'application/octet-stream'),
                 ('Content-Disposition',
                  "attachment; filename*=utf-8''%s" % (encoded_filename,)),
                 ]
             start_response('200 OK', headers)
-            return export_archive(history, root, revid, format)
+            return export_archive(history, root, revid, archive_format)
         else:
             raise httpexceptions.HTTPSeeOther('/')

=== modified file 'loggerhead/exporter.py'
--- loggerhead/exporter.py	2011-06-28 15:55:36 +0000
+++ loggerhead/exporter.py	2011-11-24 07:42:58 +0000
@@ -16,6 +16,16 @@
 
 
 class ExporterFileObject(object):
+    """Shim that accumulates temporarily written out data.
+
+    There are python tarfile classes that want to write to a file like object.
+    We want to stream data.  But wsgi assumes it can pull data from the
+    handler, rather than having bytes pushed.
+
+    So this class holds the data temporarily, until it is pulled.  It 
+    should never buffer everything because as soon as a chunk is produced, 
+    wsgi will be given the chance to take it.
+    """
 
     def __init__(self):
         self._buffer = []
@@ -29,18 +39,23 @@
         finally:
             self._buffer = []
 
-
-def export_archive(history, root, revid, format=".tar.gz"):
+    def close(self):
+        pass
+
+
+def export_archive(history, root, revid, archive_format):
     """Export tree contents to an archive
 
     :param history: Instance of history to export
     :param root: Root location inside the archive.
     :param revid: Revision to export
-    :param format: Format of the archive
+    :param archive_format: Format of the archive, eg 'tar.gz'.
     """
     fileobj = ExporterFileObject()
     tree = history._branch.repository.revision_tree(revid)
-    for _ in get_export_generator(tree=tree, root=root, fileobj=fileobj, format=format):
+    import pdb;pdb.set_trace()
+    for _ in get_export_generator(tree=tree, root=root, fileobj=fileobj,
+        format=archive_format):
         yield fileobj.get_buffer()
     # Might have additonal contents written
     yield fileobj.get_buffer()

=== modified file 'loggerhead/tests/test_controllers.py'
--- loggerhead/tests/test_controllers.py	2011-11-24 07:24:10 +0000
+++ loggerhead/tests/test_controllers.py	2011-11-24 07:42:58 +0000
@@ -300,6 +300,7 @@
         f = tempfile.NamedTemporaryFile()
         try:
             f.write(content_bytes)
+            f.flush()
             tarfile.open(f.name, mode='r|' + self.compression)
         finally:
             f.close()
@@ -316,7 +317,7 @@
         response = app.get('/tarball')
         self.assertThat(
             response.body,
-            IsTarfile(''))
+            IsTarfile('gz'))
         # Maybe the c-t should be more specific, but this is probably good for
         # making sure it gets saved without the client trying to decompress it
         # or anything.
@@ -325,4 +326,4 @@
             'application/octet-stream')
         self.assertEquals(
             response.header('Content-Disposition'),
-            "attachment; filename*=utf-8''branch.tar")
+            "attachment; filename*=utf-8''branch.tgz")

